/*
    Copyright 2008 Henry de Valence <hdevalence@gmail.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MARBLE_ONFRUNNER_H
#define MARBLE_ONFRUNNER_H

#include "MarbleAbstractRunner.h"

#include <QtCore/QString>

class QHttp;
class QBuffer;

namespace Marble
{
//Openstreetmap Name Finder
class OnfRunner : public MarbleAbstractRunner
{
    Q_OBJECT
public:
    explicit OnfRunner(QObject *parent = 0);
    ~OnfRunner();
    GeoDataFeature::GeoDataVisualCategory category() const;

public slots:
    void slotRequestFinished( int id, bool error );

protected:
    virtual void run();

private:
    void fail();
    QHttp *m_http;
    QBuffer *m_buffer;
};

}

#endif
